Module tiles

Module tiles 

Structs

ErrorNotTileable
ImageTiler
Image tile generator
IntoTilesIter
An iterator that splits a mutable slice into tiles of specified width and height.
Tile
Represents a rectangular tile within an image buffer.
TileIterMut
An iterator that allows mutable access to the lines of a Tile.

Traits

TilesMut
A trait for types that can be partitioned into mutable tiles.